==> haskell-tz-0.1.3.6-114-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-tz.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 tz
version:              0.1.3.6
visibility:           public
id:                   tz-0.1.3.6-6T2KSCf3w0V8VNqCzk5lYa
key:                  tz-0.1.3.6-6T2KSCf3w0V8VNqCzk5lYa
license:              Apache-2.0
maintainer:           Janus Troelsen <ysangkok@gmail.com>
author:               Mihaly Barasz, Gergely Risko
stability:            experimental
homepage:             https://github.com/ysangkok/haskell-tz
synopsis:             Efficient time zone handling
description:
    The goal of this package is to provide a library that can read time
    zone info files (aka. Olson files), and does time zone conversions
    in a /pure/ and /efficient/ way.

    We also provide platform-independent and/or compiled-in access to
    the standard Time Zone Dabase by the means of the companion @tzdata@
    package <http://hackage.haskell.org/package/tzdata>.

    The package is currently in an alpha phase, I'\''m still experimenting
    with different ideas wrt. scope\/API\/implementation\/etc. All
    comments are welcome!

category:             Data
abi:                  62f02faf860c7e082e8e6bf878521b5a
exposed:              True
exposed-modules:
    Data.Time.Zones Data.Time.Zones.All Data.Time.Zones.Internal
    Data.Time.Zones.Read Data.Time.Zones.Types

import-dirs:          /usr/lib/ghc-9.4.8/site-local/tz-0.1.3.6
library-dirs:         /usr/lib/ghc-9.4.8/site-local/tz-0.1.3.6
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/tz-0.1.3.6
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-tz
hs-libraries:         HStz-0.1.3.6-6T2KSCf3w0V8VNqCzk5lYa
depends:
    base-4.17.2.1 binary-0.8.9.1 bytestring-0.11.5.3 containers-0.6.7
    data-default-0.7.1.1-HuI8bY4bNR4F11jcRg6vOi deepseq-1.4.8.0
    time-1.12.2 tzdata-0.2.20250115.0-hsj4gn5o3N8iBmuULB6UJ
    vector-0.13.1.0-DP5vqiFKsIZ25TyoutQAjD

haddock-interfaces:   /usr/share/doc/haskell-tz/html/tz.haddock
haddock-html:         /usr/share/doc/haskell-tz/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-tz-0.1.3.6-115-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-tz.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 tz
version:              0.1.3.6
visibility:           public
id:                   tz-0.1.3.6-842sitv9hKX3Vf8dPSfr6O
key:                  tz-0.1.3.6-842sitv9hKX3Vf8dPSfr6O
license:              Apache-2.0
maintainer:           Janus Troelsen <ysangkok@gmail.com>
author:               Mihaly Barasz, Gergely Risko
stability:            experimental
homepage:             https://github.com/ysangkok/haskell-tz
synopsis:             Efficient time zone handling
description:
    The goal of this package is to provide a library that can read time
    zone info files (aka. Olson files), and does time zone conversions
    in a /pure/ and /efficient/ way.

    We also provide platform-independent and/or compiled-in access to
    the standard Time Zone Dabase by the means of the companion @tzdata@
    package <http://hackage.haskell.org/package/tzdata>.

    The package is currently in an alpha phase, I'\''m still experimenting
    with different ideas wrt. scope\/API\/implementation\/etc. All
    comments are welcome!

category:             Data
abi:                  ede5c4c3db6d60f1512f3ba9ff306d02
exposed:              True
exposed-modules:
    Data.Time.Zones Data.Time.Zones.All Data.Time.Zones.Internal
    Data.Time.Zones.Read Data.Time.Zones.Types

import-dirs:          /usr/lib/ghc-9.4.8/site-local/tz-0.1.3.6
library-dirs:         /usr/lib/ghc-9.4.8/site-local/tz-0.1.3.6
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/tz-0.1.3.6
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-tz
hs-libraries:         HStz-0.1.3.6-842sitv9hKX3Vf8dPSfr6O
depends:
    base-4.17.2.1 binary-0.8.9.1 bytestring-0.11.5.3 containers-0.6.7
    data-default-0.7.1.1-HuI8bY4bNR4F11jcRg6vOi deepseq-1.4.8.0
    time-1.12.2 tzdata-0.2.20250115.0-8zart0dlqWvJ4hoTCarOMU
    vector-0.13.1.0-93FGbMU4lvK4yKJkYGTpJX

haddock-interfaces:   /usr/share/doc/haskell-tz/html/tz.haddock
haddock-html:         /usr/share/doc/haskell-tz/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
